Index: /anuga_work/production/busselton/busselton_rerun/Arc_asc2raster_GDA94z50.py
===================================================================
--- /anuga_work/production/busselton/busselton_rerun/Arc_asc2raster_GDA94z50.py	(revision 7384)
+++ /anuga_work/production/busselton/busselton_rerun/Arc_asc2raster_GDA94z50.py	(revision 7385)
@@ -32,5 +32,5 @@
 time_dir6 = '20090330_120458_run_final_0_27283_Bt_kvanputt'
 
-time_dirs = [time_dir6] #1, time_dir2, time_dir3, time_dir4, time_dir5]
+time_dirs = [time_dir1] #1, time_dir2, time_dir3, time_dir4, time_dir5]
    
 for time_dir in time_dirs:
@@ -57,5 +57,5 @@
 
     generate_filename = []
-    input_ascii = glob.glob(folder + '*depth_max.asc')
+    input_ascii = glob.glob(folder + '*elevation.asc')
 
     for infile in input_ascii:
@@ -78,8 +78,8 @@
                                                    ",PROJECTION['Transverse_Mercator'],PARAMETER['False_Easting',500000.0],PARAMETER['False_Northing',10000000.0],PARAMETER['Central_Meridian',117.0],PARAMETER['Scale_Factor',0.9996]"
                                                    ",PARAMETER['Latitude_Of_Origin',0.0],UNIT['Meter',1.0]]")
-        output_extract = output_DEM + '_E'
-        print 'Output Extract ',output_extract
-        print 'Process: Extract by Mask'
-        gp.ExtractByMask_sa(output_DEM, land, output_extract)
+##        output_extract = output_DEM + '_E'
+##        print 'Output Extract ',output_extract
+##        print 'Process: Extract by Mask'
+##        gp.ExtractByMask_sa(output_DEM, land, output_extract)
 
 
Index: /anuga_work/production/carnarvon/carnarvon_rerun/Arc_asc2raster_GDA94z49.py
===================================================================
--- /anuga_work/production/carnarvon/carnarvon_rerun/Arc_asc2raster_GDA94z49.py	(revision 7384)
+++ /anuga_work/production/carnarvon/carnarvon_rerun/Arc_asc2raster_GDA94z49.py	(revision 7385)
@@ -32,5 +32,5 @@
 time_dir6 = '20090327_160753_run_final_0_27283_Bt_kvanputt'
 
-time_dirs = [time_dir1, time_dir2, time_dir3, time_dir4, time_dir5, time_dir6]   
+time_dirs = [time_dir1] #, time_dir2, time_dir3, time_dir4, time_dir5, time_dir6]   
 
 for time_dir in time_dirs:
@@ -55,5 +55,5 @@
 
     generate_filename = []
-    input_ascii = glob.glob(folder + '*depth_max.asc')
+    input_ascii = glob.glob(folder + '*elevation.asc')
 
     for infile in input_ascii:
@@ -80,8 +80,8 @@
 
  
-        print 'Process: Extract by Mask'
-        output_extract = output_DEM + '_E'
-        print 'Output Extract ',output_extract
-        gp.ExtractByMask_sa(output_DEM, land, output_extract)
+##        print 'Process: Extract by Mask'
+##        output_extract = output_DEM + '_E'
+##        print 'Output Extract ',output_extract
+##        gp.ExtractByMask_sa(output_DEM, land, output_extract)
 
 
Index: /anuga_work/production/dampier_2009/Arc_asc2raster_GDA94z50.py
===================================================================
--- /anuga_work/production/dampier_2009/Arc_asc2raster_GDA94z50.py	(revision 7384)
+++ /anuga_work/production/dampier_2009/Arc_asc2raster_GDA94z50.py	(revision 7385)
@@ -22,14 +22,10 @@
 gp.overwriteoutput = 1
 
-scenario_dir = "\\\\nas2\\gemd\\georisk_models\\inundation\\data\\western_australia\\onslow_tsunami_scenario_2009\\"
+scenario_dir = "\\\\nas2\\gemd\\georisk_models\\inundation\\data\\western_australia\\dampier_tsunami_scenario_2009\\"
 output_dir="anuga\\outputs\\"
 
-time_dir1 = '20090616_154908_run_final_0.0_27283_mhingee'
-##time_dir2 = '20090416_072538_run_final_0_27338_1307_Tb__kvanputt'
-##time_dir3 = '20090417_021634_run_final_0_70337_1307_Tb__kvanputt'
+time_dir1 = '20090817_150959_run_final_0.0_70408_kvanputt'
 
-##time_dir2 = '20090422_102457_run_final_0_70844_1307_Tb_internal_mhingee'
-
-time_dirs = [time_dir1]#, time_dir2]#, time_dir3]
+time_dirs = [time_dir1]
 
 for time_dir in time_dirs:
@@ -48,11 +44,11 @@
     
     #replication dictionary
-    replicate = (('onslow', ''),('_', ''),('max','_M'),
-                 ('CBD', 'CDB'),('All',''),
+    replicate = (('dampier', ''),('_', ''),('max','_M'),
+                 ('CBD', 'CDB'),('Dampier', 'Damp'),('Karratha', 'Karr')
                  ('depth','_depth'),('speed', '_speed'),
-                 ('elevation', '_ele_'), ('stage','_stage'))
+                 ('elevation', '_ele'), ('stage','_stage'))
 
     generate_filename = []
-    input_ascii = glob.glob(folder + '*elevation.asc')
+    input_ascii = glob.glob(folder + '*.asc')
 
     for infile in input_ascii:
@@ -72,5 +68,4 @@
 
         print 'Process: Define Projection'
-        #GDA_1994_MGA_Zone_54
         gp.DefineProjection_management(output_DEM, "PROJCS['GDA_1994_MGA_Zone_50',GEOGCS['GCS_GDA_1994',DATUM['D_GDA_1994',SPHEROID['GRS_1980',6378137.0,298.257222101]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]]"
                                                    ",PROJECTION['Transverse_Mercator'],PARAMETER['False_Easting',500000.0],PARAMETER['False_Northing',10000000.0],PARAMETER['Central_Meridian',117.0],PARAMETER['Scale_Factor',0.9996]"
Index: /anuga_work/production/dampier_2009/project.py
===================================================================
--- /anuga_work/production/dampier_2009/project.py	(revision 7384)
+++ /anuga_work/production/dampier_2009/project.py	(revision 7385)
@@ -29,5 +29,5 @@
 zone = 50               # specify UTM zone of model
 central_meridian = None 
-event_number = 27283    # 27255,27283 the event number or the mux file name
+event_number = 70408    # 27255,27283 the event number or the mux file name
 alpha = 0.1             # smoothing parameter for mesh
 friction=0.01           # manning's friction coefficient
@@ -60,8 +60,8 @@
 # Used in build_elevation.py
 # Format for ascii grids, as produced in ArcGIS + a projection file
-ascii_grid_filenames = []
+ascii_grid_filenames = ['topo_to_raster_0_30', 'land_final_240107']
 
 # Format for point is x,y,elevation (with header)
-point_filenames = []
+point_filenames = ['Hydro_fair_chart.txt', 'coast_line.txt']
 
 ### Add csv header list to all files in point_filenames
@@ -79,35 +79,12 @@
 # Used in run_model.py
 # Format for points easting,northing (no header)                    
-interior_regions_data = [['dampier_region.csv', 3000],
-                         ['dampier_aos.csv', 800],
-                         ['dampier_aoi.csv', 500],
-                         ['dampier_north_aos.csv', 800],
-                         ['dampier_north_aoi.csv', 500],
-                         ['karratha_aos.csv', 800],
-                         ['karratha_aoi.csv', 500],
-                         ['ref_ne_islands1.csv', 1500],  ## islands to the NE and headland between dampier and karratha
-                         ['ref_ne_islands2.csv', 1500],  ## island in entrance to bay for Karratha
-##                         ['nwislands.csv', 1500],   ## all islands to the NW:
-                         ['ref_nw4.csv', 1500],
-                         ['ref_nw5.csv', 1500],
-                         ['ref_nw6.csv', 1500],
-                         ['ref_nw7.csv', 1500],
-                         ['ref_nw8.csv', 1500],
-                         ['island0.csv', 10000],   ## make large triangles for land areas of islands to reduce no. of triangles
-                         ['island1.csv', 10000],
-                         ['island2.csv', 10000],
-                         ['island3.csv', 10000],
-                         ['island4.csv', 10000],
-                         ['island5.csv', 10000],
-                         ['island6.csv', 10000],
-                         ['island7.csv', 10000],
-                         ['island8.csv', 10000]]
-
-PriorityArea_filename = None
+interior_regions_data = [['dampier_aoi.csv', 500],
+                         ['karratha_aoi.csv', 500]]
+
+PriorityArea_filename = 'aos.csv'
     
 # LAND - used to set the initial stage/water to be offcoast only
 # Used in run_model.py.  Format for points easting,northing,id,value
-land_initial_conditions_filename = [['mainland_only.csv',0],  ## these are all placeholders until proper initial conditions made
-                                    ['island0.csv',0]]
+land_initial_conditions_filename = 'initial_conditions_simple.csv'
 
 # GAUGES - for creating timeseries at a specific point
@@ -153,21 +130,14 @@
 
 # ASCII export grid for Dampier
-##xmin = 
-##xmax = 
-##ymin = 
-##ymax = 
+xminDampier = 465000
+xmaxDampier = 471000
+yminDampier = 7713000
+ymaxDampier = 7719000
 
 # ASCII export grid for Karratha
-##xmin = 
-##xmax = 
-##ymin = 
-##ymax =
-
-# ASCII export grid for Dampier northern area
-##xmin = 
-##xmax = 
-##ymin = 
-##ymax =
-
+xminKarratha = 475700
+xmaxKarratha = 489600
+yminKarratha = 7707000
+ymaxKarratha = 7718000
 
 ################################################################################
Index: /anuga_work/production/dampier_2009/setup_model.py
===================================================================
--- /anuga_work/production/dampier_2009/setup_model.py	(revision 7384)
+++ /anuga_work/production/dampier_2009/setup_model.py	(revision 7385)
@@ -27,8 +27,4 @@
     sanity_error = True
 
-if os.getenv(project.ENV_MUXHOME) is None:
-    print "Environment variable '%s' is not set" % project.ENV_MUXHOME
-    sanity_error = True
-
 #-------------------------------------------------------------------------------
 # Check filename strings that MUST be set
@@ -52,8 +48,4 @@
 if not exists(project.home):
     print "Sorry, data directory '%s' doesn't exist" % project.home
-    sanity_error = True
-    
-if not exists(project.muxhome):
-    print "Sorry, MUX directory '%s' doesn't exist" % project.muxhome
     sanity_error = True
     
@@ -84,15 +76,4 @@
     print "Sorry, gauges directory '%s' doesn't exist" % project.gauges_folder
     sanity_error = True
-
-if not exists(project.mux_data_folder):
-    print "Sorry, mux data directory '%s' doesn't exist" % project.mux_data_folder
-    sanity_error = True
-
-# if multi_mux is True, check if multi-mux file exists
-if project.multi_mux:
-    if not exists(project.mux_input):
-        print ("Sorry, MUX input file '%s' doesn't exist"
-               % project.mux_input)
-        sanity_error = True
 
 #-----
@@ -166,4 +147,5 @@
            % type(project.land_initial_conditions_filename))
     raise Exception, msg
+
 # Create list of interior polygons with scaling factor
 project.interior_regions = []
Index: /anuga_work/production/exmouth_2009/project.py
===================================================================
--- /anuga_work/production/exmouth_2009/project.py	(revision 7384)
+++ /anuga_work/production/exmouth_2009/project.py	(revision 7385)
@@ -8,5 +8,4 @@
 from time import localtime, strftime, gmtime
 from os.path import join, exists
-from anuga.lib.add_csv_header.add_csv_header import add_csv_header
 
 #-------------------------------------------------------------------------------
@@ -26,8 +25,8 @@
 # Model specific parameters.
 # One or all can be changed each time the run_model script is executed
-tide = 0.0              # 3.6 difference between MSL and HAT in metres
-zone = None               # specify UTM zone of model
-central_meridian = 114.0 
-event_number = 27283    # 27255,27283 the event number or the mux file name
+tide = 0                # difference between MSL and HAT in metres
+zone = None
+central_meridian = 114   # specify the central merdian for the data
+event_number = 27283    # the event number or the mux file name
 alpha = 0.1             # smoothing parameter for mesh
 friction=0.01           # manning's friction coefficient
@@ -60,16 +59,13 @@
 # Used in build_elevation.py
 # Format for ascii grids, as produced in ArcGIS + a projection file
-##ascii_grid_filenames = ['extract_dli',
-##                        'extract_dted']
-ascii_grid_filenames = []
-
-# Format for point is x,y,elevation (with header)
+ascii_grid_filenames = ['extract_dli', 'extract_dted'] # onshore elevation data
+
+
+    # Format for point is x,y,elevation (with header)
 point_filenames = ['coastline.txt',  # coastline points with 0m elevation
                    'Exmouth.txt',    # combined bathymetry for most of model
-                   'extract_dgapcs100.txt',  # interpolated bathy. for gap in data just NE of Exmouth itself
-                   'extract_rivoli.txt',     # interpolated bathy. for gap in data near Rivoli islands
-                   'extract_dli.txt',        # onshore elevation data
-                   'extract_dted.txt',       # more onshore elevation data
-                   'exmouth_aoi_aos_gridded.txt']  # fine grid of data interpolated from Exmouth.txt for use in refined grids (aoi and aos)
+                   'extract_dgap_cs100.txt',  # interpolated bathy. for gap in data just NE of Exmouth itself
+                   'extract_rivoli100.txt']     # interpolated bathy. for gap in data near Rivoli islands
+                   #'exmouth_aoi_aos_gridded.txt']  # fine grid of data interpolated from Exmouth.txt for use in refined grids (aoi and aos)
 
 ### Add csv header list to all files in point_filenames
@@ -81,39 +77,32 @@
 # Used in build_elevation.py
 # Format for points easting,northing (no header)
-bounding_polygon_filename = 'poly_all_MH.csv'
-bounding_polygon_maxarea = 100000
+bounding_polygon_filename = 'bounding_polygon.csv'
+bounding_polygon_maxarea = 1000000
 
 # INTERIOR REGIONS -  for designing the mesh
 # Used in run_model.py
 # Format for points easting,northing (no header)                    
-interior_regions_data = [['sw_MH.csv', 3000],
-                         ['aos_MH.csv', 800],
-                         ['aoi_small_MH.csv', 500],
-                         ['island1_MH.csv', 3000],
-                         ['island2_MH.csv', 3000],
-                         ['island3_MH.csv', 3000],
-                         ['island4_MH.csv', 3000],
-                         ['island5_MH.csv', 3000]]#,
-##                         ['island6_MH.csv', 3000]]
-
-PriorityArea_filename = None
+
+interior_regions_data = [['aoi.csv', 500]]
+PriorityArea_filename = 'aos.csv'
     
 # LAND - used to set the initial stage/water to be offcoast only
-# Used in run_model.py.  Format for points easting,northing,id,value
-land_initial_conditions_filename = 'initial_condition_comb.csv'
+# Used in run_model.py.  Format for points easting,northing (no header)
+land_initial_conditions_filename = 'initial_conditions_simple.csv'
 
 # GAUGES - for creating timeseries at a specific point
 # Used in get_timeseries.py.  
 # Format easting,northing,name,elevation (with header)
-gauges_filename = ''
+gauges_filename = '' #'TideGaugesPoints.csv' #'tsunamipointsMGA.csv'
+
 # BUILDINGS EXPOSURE - for identifying inundated houses
 # Used in run_building_inundation.py
 # Format latitude,longitude etc (geographic)
-building_exposure_filename = 'busselton_res_clip.csv' # from NEXIS
+building_exposure_filename = '' # from NEXIS
 
 # AREA OF IMAGES - Extent of each image to find out highest runup
 # Header - easting,northing,id,value
 # Used in get_runup.py
-images_filename = ''
+images_filename = 'images.csv'
 
 # BOUNDING POLYGON - used in build_boundary.py and run_model.py respectively
@@ -145,9 +134,8 @@
 
 # ASCII export grid for Exmouth
-xminExmouth = 511616
-xmaxExmouth = 516764
-yminExmouth = 7568731
-ymaxExmouth = 7577540
-
+xminExmouth = 511000
+xmaxExmouth = 516000
+yminExmouth = 7567700
+ymaxExmouth = 7576500
 
 ################################################################################
@@ -201,9 +189,4 @@
 event_folder = join(boundaries_folder, str(event_number))
 
-### Add csv header list to all files in point_filenames
-##headerlist = ['x', 'y', 'elevation'] 
-##for f in point_filenames:
-##    add_csv_header(join(topographies_folder, f), headerlist)
-
 # MUX data files
 # Directory containing the MUX data files to be used with EventSelection.
Index: /anuga_work/production/exmouth_2009/run_model.py
===================================================================
--- /anuga_work/production/exmouth_2009/run_model.py	(revision 7384)
+++ /anuga_work/production/exmouth_2009/run_model.py	(revision 7385)
@@ -137,5 +137,4 @@
 Br = Reflective_boundary(domain)
 Bt = Transmissive_stage_zero_momentum_boundary(domain)
-Bd = Dirichlet_boundary([project.tide, 0, 0])
 Bf = Field_boundary(project.event_sts+'.sts',
                     domain, mean_stage=project.tide,
Index: /anuga_work/production/geraldton/geraldton_rerun/Arc_asc2raster_GDA94z50.py
===================================================================
--- /anuga_work/production/geraldton/geraldton_rerun/Arc_asc2raster_GDA94z50.py	(revision 7384)
+++ /anuga_work/production/geraldton/geraldton_rerun/Arc_asc2raster_GDA94z50.py	(revision 7385)
@@ -32,5 +32,5 @@
 time_dir6 = '20090327_160043_run_final_0_27255_Bt_kvanputt'
 
-time_dirs = [time_dir1, time_dir2, time_dir3]
+time_dirs = [time_dir1] #, time_dir2, time_dir3]
 
 for time_dir in time_dirs:
@@ -56,5 +56,5 @@
 
     generate_filename = []
-    input_ascii = glob.glob(folder + '*speed_max.asc')
+    input_ascii = glob.glob(folder + '*elevation.asc')
 
     for infile in input_ascii:
Index: /anuga_work/production/hobart_2009/export_results_max.py
===================================================================
--- /anuga_work/production/hobart_2009/export_results_max.py	(revision 7384)
+++ /anuga_work/production/hobart_2009/export_results_max.py	(revision 7385)
@@ -21,18 +21,18 @@
 
 directory = project.output_folder
-time_dir1 = '20090714_162136_run_final_0_58260_None_kvanputt'
+time_dir1 = '20090504_124158_run_final_0_58068_small_kvanputt'
 time_dir2 = '20090714_162041_run_final_0.8_58292_None_kvanputt'
 time_dir3 = '20090714_161944_run_final_0.8_58280_None_kvanputt'
 time_dir4 = '20090714_161740_run_final_0.8_58260_None_kvanputt'
 
-time_dirs = [time_dir1, time_dir2, time_dir3, time_dir4]  
+time_dirs = [time_dir1]  
 
 # sww filename extensions ie. hobart_time_17640_0.sww, input into list 17640
 # make sure numbers are in sequential order
-times = [16980, 33960, 50940]
+times = [22680, 45360, 68040]
             
 #Modify the cellsize value to set the size of the raster you require
 #Take into account mesh size when aplying this paramater
-cellsize = 20 #250
+cellsize = 250 #250
 
 #Now set the timestep at which you want the raster generated.
@@ -120,9 +120,12 @@
             print 'which var=%s' % which_var
             #print 'asc_name ', str(asc_name)
-            if times == []:     
-                print 'Only one sww file, no Max file required'
+            if len(names) >1:
+                maxasc_outname = join(directory, time_dir, project.scenario_name)+'_'+which_area+'_'+which_var+'_max.asc'
+
+                print 'max asc outname ', maxasc_outname
+                print 'asc_name ', str(asc_name)
+                
+                MaxAsc(maxasc_outname, asc_name)
             else:
-                print 'Multiple sww files'
-                maxasc_outname = join(directory, time_dir, project.scenario_name)+'_'+which_area+'_'+which_var+'_max.asc'
-                print 'maxasc_outname = ', maxasc_outname
-                MaxAsc(maxasc_outname, asc_name)
+                print 'Only one sww file, no Max file required' 
+
Index: /anuga_work/production/onslow_2009_june/Arc_asc2raster_GDA94z50.py
===================================================================
--- /anuga_work/production/onslow_2009_june/Arc_asc2raster_GDA94z50.py	(revision 7384)
+++ /anuga_work/production/onslow_2009_june/Arc_asc2raster_GDA94z50.py	(revision 7385)
@@ -25,11 +25,7 @@
 output_dir="anuga\\outputs\\"
 
-time_dir1 = '20090617_110255_run_final_0.0_27283_mhingee'
-##time_dir2 = '20090416_072538_run_final_0_27338_1307_Tb__kvanputt'
-##time_dir3 = '20090417_021634_run_final_0_70337_1307_Tb__kvanputt'
+time_dir1 = '20090817_171542_run_final_0.0_27283_kvanputt'
 
-##time_dir2 = '20090422_102457_run_final_0_70844_1307_Tb_internal_mhingee'
-
-time_dirs = [time_dir1]#, time_dir2]#, time_dir3]
+time_dirs = [time_dir1]
 
 for time_dir in time_dirs:
@@ -40,6 +36,6 @@
 ##    ocean = scenario_dir + "map_work\\\port_hedland.gdb\\outlines\\initial_conditions_ocean"
 
-##    print 'Process: Create File GDB'
-##    gp.CreateFileGDB_management(folder, "raster")
+    print 'Process: Create File GDB'
+    gp.CreateFileGDB_management(folder, "raster")
 
     gp.Workspace = raster_gbd
@@ -48,11 +44,11 @@
     
     #replication dictionary
-    replicate = (('onslow', 'o'),('_', ''),('max','_M'),
-                 ('CBD', 'CDB'),('All',''),
+    replicate = (('onslow', ''),('_', ''),('max','_M'),
+                 ('CBD', 'CDB'),
                  ('depth','_depth'),('speed', '_speed'),
-                 ('elevation', '_ele_'), ('stage','_stage'))
+                 ('elevation', '_ele'), ('stage','_stage'))
 
     generate_filename = []
-    input_ascii = glob.glob(folder + '*w_O*.asc')
+    input_ascii = glob.glob(folder + '*.asc')
 
     for infile in input_ascii:
@@ -72,5 +68,4 @@
 
         print 'Process: Define Projection'
-        #GDA_1994_MGA_Zone_54
         gp.DefineProjection_management(output_DEM, "PROJCS['GDA_1994_MGA_Zone_50',GEOGCS['GCS_GDA_1994',DATUM['D_GDA_1994',SPHEROID['GRS_1980',6378137.0,298.257222101]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]]"
                                                    ",PROJECTION['Transverse_Mercator'],PARAMETER['False_Easting',500000.0],PARAMETER['False_Northing',10000000.0],PARAMETER['Central_Meridian',117.0],PARAMETER['Scale_Factor',0.9996]"
Index: uga_work/production/onslow_2009_june/export_results.py
===================================================================
--- /anuga_work/production/onslow_2009_june/export_results.py	(revision 7384)
+++ 	(revision )
@@ -1,121 +1,0 @@
-"""
-Generates ascii grids of nominated areas -
-Input: sww file from run_perth.py
-       boundaries for grids from project.py
-Outputs: ascii grids of specified variables
-Stored in the 'outputs_dir' folder for respective .sww file
-
-Note:
-If producing a grid for the enitre extent cellsize should be greater than 30m
-If producing grids for inundation area resolution should be greater than mesh (ie ~22m)
-"""
-
-import project, os
-import sys
-from os.path import join
-from anuga.lib.maxasc.maxasc import MaxAsc
-from anuga.shallow_water.data_manager import convert_dem_from_ascii2netcdf, dem2pts
-from anuga.shallow_water.data_manager import sww2dem
-from os import sep
-
-
-directory = project.output_folder
-
-##time_dir1 = '20090616_154908_run_final_0.0_27283_mhingee'
-time_dir2 = '20090617_110255_run_final_0.0_27283_mhingee'
-##time_dir3 = ''
-##time_dir4 = ''
-##time_dir5 = ''
-##time_dir6 = ''
-##
-time_dirs = [time_dir2]#, time_dir2]# , time_dir4, time_dir5, time_dir6]
-  
-
-##cellsize = 250
-cellsize = 20
-
-#timestep = None    # None means no timestep!
-timestep = 0
-
-######
-# Set the special areas of interest.  If none, do: area='All'
-######
-
-area = ['Onslow']  # strings must match keys in var_equations below
-##area = ['All']      # 'All' means no special areas - the whole thing
-
-######
-# Define allowed variable names and associated equations to generate values.
-# This would not normally change.
-######
-var_equations = {'stage':     'stage',
-                 'momentum':  '(xmomentum**2 + ymomentum**2)**0.5',
-                 'depth':     'stage-elevation',
-                 'speed':     '(xmomentum**2 + ymomentum**2)**0.5/(stage-elevation+1.e-6)',
-                 'elevation': 'elevation' }
-
-# one or more key strings from var_equations above
-var = ['elevation','stage']
-
-######
-# Start running the various conversions we require.
-######
-
-for which_var in var:
-    if which_var not in var_equations:
-        print 'Unrecognized variable name: %s' % which_var
-        break
-
-    for which_area in area:
-        if which_area == 'All':
-            easting_min = None
-            easting_max = None
-            northing_min = None
-            northing_max = None
-        else:
-            try:
-                easting_min = eval('project.xmin%s' % which_area)
-                easting_max = eval('project.xmax%s' % which_area)
-                northing_min = eval('project.ymin%s' % which_area)
-                northing_max = eval('project.ymax%s' % which_area)
-            except AttributeError:
-                print 'Unrecognized area name: %s' % which_area
-                break
-
-        for time_dir in time_dirs:
-
-            name1 = join(directory, time_dir, project.scenario_name)
-            #name2 = join(directory, time_dir, project.scenario_name)+'_time_39600_0'
-            #name3 = join(directory, time_dir, project.scenario_name)+'_time_79200_0'
-
-            names = [name1] #, name2]#, name3]
-      
-           # asc_name = []   
-               
-            for name in names:
-                         
-                outname = name + '_' + which_area + '_' + which_var
-                quantityname = var_equations[which_var]
-
-                print 'start sww2dem: time_dir=%s' % time_dir
-                
-                sww2dem(name, basename_out = outname,
-                            quantity = quantityname,
-                            timestep = timestep,
-                            cellsize = cellsize,      
-                            easting_min = easting_min,
-                            easting_max = easting_max,
-                            northing_min = northing_min,
-                            northing_max = northing_max,        
-                            reduction = max, 
-                            verbose = True,
-                            format = 'asc')
-
-##                asc_name.append(outname + '.asc')
-##    
-##            maxasc_outname = join(directory, time_dir, project.scenario_name)+'_'+which_area+'_'+which_var+'_max.asc'
-##
-##            print 'max asc outname ', maxasc_outname
-##            print 'asc_name ', str(asc_name)
-##            
-##            MaxAsc(maxasc_outname, asc_name)
Index: /anuga_work/production/onslow_2009_june/setup_model.py
===================================================================
--- /anuga_work/production/onslow_2009_june/setup_model.py	(revision 7384)
+++ /anuga_work/production/onslow_2009_june/setup_model.py	(revision 7385)
@@ -169,5 +169,5 @@
 project.interior_regions = []
 
-if project.PriorityArea_filename is not None:
+if project.interior_regions_combined_filename is not None:
     polygons, maxareas = csv2polygons(project.PriorityAreas)
     print 'Creating %d internal polygons' % len(polygons)
Index: /anuga_work/production/perth/perth_rerun/Arc_asc2raster_GDA94z50.py
===================================================================
--- /anuga_work/production/perth/perth_rerun/Arc_asc2raster_GDA94z50.py	(revision 7384)
+++ /anuga_work/production/perth/perth_rerun/Arc_asc2raster_GDA94z50.py	(revision 7385)
@@ -32,5 +32,5 @@
 time_dir6 = '20090327_155803_run_final_0_68693_Bt_kvanputt'
 
-time_dirs = [time_dir4, time_dir5, time_dir6] #time_dir1, time_dir2, time_dir3, 
+time_dirs = [time_dir1] #4, time_dir5, time_dir6] #time_dir1, time_dir2, time_dir3, 
  
 for time_dir in time_dirs:
@@ -57,5 +57,5 @@
 
     generate_filename = []
-    input_ascii = glob.glob(folder + '*speed_max.asc')
+    input_ascii = glob.glob(folder + '*elevation.asc')
     print time_dir
 
Index: /anuga_work/production/pt_hedland_2009/Arc_asc2raster_GDA94z50.py
===================================================================
--- /anuga_work/production/pt_hedland_2009/Arc_asc2raster_GDA94z50.py	(revision 7384)
+++ /anuga_work/production/pt_hedland_2009/Arc_asc2raster_GDA94z50.py	(revision 7385)
@@ -25,11 +25,7 @@
 output_dir="anuga\\outputs\\"
 
-time_dir1 = '20090615_151314_run_final_0.0_27283_mhingee'
-##time_dir2 = '20090416_072538_run_final_0_27338_1307_Tb__kvanputt'
-##time_dir3 = '20090417_021634_run_final_0_70337_1307_Tb__kvanputt'
+time_dir1 = '20090818_133107_run_final_0.0_27283_kvanputt'
 
-##time_dir2 = '20090422_102457_run_final_0_70844_1307_Tb_internal_mhingee'
-
-time_dirs = [time_dir1]#, time_dir2]#, time_dir3]
+time_dirs = [time_dir1]
 
 for time_dir in time_dirs:
@@ -40,6 +36,6 @@
 ##    ocean = scenario_dir + "map_work\\\port_hedland.gdb\\outlines\\initial_conditions_ocean"
 
-##    print 'Process: Create File GDB'
-##    gp.CreateFileGDB_management(folder, "raster")
+    print 'Process: Create File GDB'
+    gp.CreateFileGDB_management(folder, "raster")
 
     gp.Workspace = raster_gbd
@@ -49,10 +45,10 @@
     #replication dictionary
     replicate = (('pt_hedland', ''),('_', ''),('max','_M'),
-                 ('CBD', 'CDB'),('All',''),
+                 ('CBD', 'CDB'), ('PtHedland', 'PH'),
                  ('depth','_depth'),('speed', '_speed'),
-                 ('elevation', '_ele_'), ('stage','_stage'))
+                 ('elevation', '_ele'), ('stage','_stage'))
 
     generate_filename = []
-    input_ascii = glob.glob(folder + '*Town*.asc')
+    input_ascii = glob.glob(folder + '*.asc')
 
     for infile in input_ascii:
@@ -72,5 +68,4 @@
 
         print 'Process: Define Projection'
-        #GDA_1994_MGA_Zone_54
         gp.DefineProjection_management(output_DEM, "PROJCS['GDA_1994_MGA_Zone_50',GEOGCS['GCS_GDA_1994',DATUM['D_GDA_1994',SPHEROID['GRS_1980',6378137.0,298.257222101]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]]"
                                                    ",PROJECTION['Transverse_Mercator'],PARAMETER['False_Easting',500000.0],PARAMETER['False_Northing',10000000.0],PARAMETER['Central_Meridian',117.0],PARAMETER['Scale_Factor',0.9996]"
Index: /anuga_work/production/pt_hedland_2009/project.py
===================================================================
--- /anuga_work/production/pt_hedland_2009/project.py	(revision 7384)
+++ /anuga_work/production/pt_hedland_2009/project.py	(revision 7385)
@@ -32,5 +32,5 @@
 friction=0.01           # manning's friction coefficient
 starttime=0             # start time for simulation
-finaltime=80000         # final time for simulation
+finaltime=1000         # final time for simulation
 
 setup = 'final'         # This can be one of three values
@@ -83,5 +83,5 @@
 # LAND - used to set the initial stage/water to be offcoast only
 # Used in run_model.py.  Format for points easting,northing,id,value
-land_initial_conditions_filename = 'initial_conditions_comb.csv'
+land_initial_conditions_filename = 'initial_conditions_simple.csv'
 
 # GAUGES - for creating timeseries at a specific point
@@ -92,5 +92,5 @@
 # Used in run_building_inundation.py
 # Format latitude,longitude etc (geographic)
-building_exposure_filename = 'busselton_res_clip.csv' # from NEXIS
+building_exposure_filename = '' # from NEXIS
 
 # AREA OF IMAGES - Extent of each image to find out highest runup
@@ -127,8 +127,8 @@
 
 # ASCII export grid for Pt Hedland
-xminTown = 659643
-xmaxTown = 676236
-yminTown = 7744216
-ymaxTown = 7757347
+xminPtHedland = 659400
+xmaxPtHedland = 676600
+yminPtHedland = 7744000
+ymaxPtHedland = 7757300
 
 

Index: /anuga_work/production/onslow_2009_june/project.py
===================================================================
--- /anuga_work/production/onslow_2009_june/project.py	(revision 7384)
+++ /anuga_work/production/onslow_2009_june/project.py	(revision 7385)
@@ -26,5 +26,5 @@
 # One or all can be changed each time the run_model script is executed
 tide = 0.0              # 3.6 difference between MSL and HAT in metres
-zone = 50               # specify UTM zone of model
+zone= 50               # specify UTM zone of model
 central_meridian = None 
 event_number = 27283    # 27255,27283 the event number or the mux file name
@@ -38,4 +38,13 @@
                         #    basic - coarse mesh
                         #    final - fine mesh, slowest
+
+# MUX input filename.
+# If a meta-file from EventSelection is used, set 'multi-mux' to True.
+# If a single MUX stem filename (*.grd) is used, set 'multi-mux' to False.
+##mux_input_filename = event_number # to be found in event_folder
+                                    # (ie boundaries/event_number/)
+##multi_mux = False
+mux_input_filename = 'event.list'
+multi_mux = True
 
 #-------------------------------------------------------------------------------
@@ -64,5 +73,4 @@
 # Format for point is x,y,elevation (with header)
 point_filenames = ['onslow_offshore_points.txt',
-                   'revised_coastline.txt',
                    'beach_survey.txt',
                    'ONS16FINAL.txt',
@@ -75,5 +83,5 @@
 ##    add_csv_header(join(topographies_folder, f), headerlist)
 
 # BOUNDING POLYGON - for data clipping and estimate of triangles in mesh
 # Used in build_elevation.py
 # Format for points easting,northing (no header)
@@ -92,9 +100,32 @@
                          ['island4_MH.csv', 3000]]
 
-PriorityArea_filename = None
+#Format for points easting,northing,id,value
+interior_regions_combined_filename = None
     
 # LAND - used to set the initial stage/water to be offcoast only
-# Used in run_model.py.  Format for points easting,northing,id,value
-land_initial_conditions_filename = 'initial_conditions_mainland.csv'
+# Used in run_model.py.
+# If a list format for points easting,northing (no header)
+
+##land_initial_conditions_filename = []
+
+#Format for points easting,northing,id,value
+land_initial_conditions_filename = 'initial_conditions_simple.csv'
+
+# MODEL BOUNDING POLYGON - used in build_boundary.py and run_model.py respectively
+# NOTE: when files are put together the points must be in sequence
+# For ease go clockwise!
+# Check the run_model.py for boundary_tags
+
+# Thinned ordering file from Hazard Map (geographic)
+# Format is index,latitude,longitude (with header)
+urs_order_filename = 'urs_order.csv'
+
+# Landward bounding points
+# Format easting,northing (no header)
+landward_boundary_filename = 'landward_boundary.csv'
+
+#-------------------------------------------------------------------------------
+# For output sww file
+#-------------------------------------------------------------------------------
 
 # GAUGES - for creating timeseries at a specific point
@@ -105,5 +136,5 @@
 # Used in run_building_inundation.py
 # Format latitude,longitude etc (geographic)
-building_exposure_filename = 'busselton_res_clip.csv' # from NEXIS
+building_exposure_filename = '' # from NEXIS
 
 # AREA OF IMAGES - Extent of each image to find out highest runup
@@ -112,36 +143,13 @@
 images_filename = ''
 
-# BOUNDING POLYGON - used in build_boundary.py and run_model.py respectively
-# NOTE: when files are put together the points must be in sequence
-# For ease go clockwise!
-# Check the run_model.py for boundary_tags
-
-# Thinned ordering file from Hazard Map (geographic)
-# Format is index,latitude,longitude (with header)
-urs_order_filename = 'urs_order.csv'
-
-# Landward bounding points
-# Format easting,northing (no header)
-landward_boundary_filename = 'landward_boundary.csv'
-
-# MUX input filename.
-# If a meta-file from EventSelection is used, set 'multi-mux' to True.
-# If a single MUX stem filename (*.grd) is used, set 'multi-mux' to False.
-##mux_input_filename = event_number # to be found in event_folder
-                                    # (ie boundaries/event_number/)
-##multi_mux = False
-mux_input_filename = 'event.list'
-multi_mux = True
-
-#-------------------------------------------------------------------------------
+
 # Clipping regions for export to asc and regions for clipping data
 # Final inundation maps should only be created in regions of the finest mesh
-#-------------------------------------------------------------------------------
 
 # ASCII export grid for Onslow
-xminOnslow = 301199
-xmaxOnslow = 311353
-yminOnslow = 7600921
-ymaxOnslow = 7609833
+xminOnslow = 301200
+xmaxOnslow = 311500
+yminOnslow = 7601000
+ymaxOnslow = 7609200
 
 
@@ -254,6 +262,6 @@
 
 #Multiple polygons in one CSV file to make internal polygons
-if not PriorityArea_filename == None:
-    PriorityAreas = join(polygons_folder, PriorityArea_filename)
-
-
+if not interior_regions_combined_filename == None:
+    interior_regions_combined = join(polygons_folder, interior_regions_combined_filename)
+
+
@@ -75,5 +83,5 @@
 ##    add_csv_header(join(topographies_folder, f), headerlist)
 
-# BOUNDING POLYGON - for data clipping and estimate of triangles in mesh
+# SIMPLE BOUNDING POLYGON - for data clipping and estimate of triangles in mesh
 # Used in build_elevation.py
 # Format for points easting,northing (no header)